static char *sccsid = "@(#) lib/exits/oltp/pc/winnt/amqzscin.c, lqm, p000, p000-L981215            1.7   98/12/11 11:59:45";
static const char * amq_copyright = \
 "Licensed Materials - Property of IBM 04L1830, 5639-B43 \
 (C) Copyright IBM Corp. 1996, 1998 All Rights Reserved \
 US Goverment Users Restricted Rights - Use, duplication or \
 disclosure restricted by GSA ADP Schedule Contract with IBM Corp.\n" ;
/*********************************************************************/
/*                                                                   */
/* Module Name: amqzscin.c                                           */
/*                                                                   */
/* Description: MQSeries XA switch program for CICS                  */
/*              XA Initialisation                                    */
/*                                                                   */
/*  Statement:     Licensed Materials - Property of IBM              */                      
/*                                                                   */      
/*                 04L1773, 5765-B73                                 */            
/*                 04L1802, 5639-B42                                 */            
/*                 04L1788, 5765-B74                                 */            
/*                 04L1816, 5765-B75                                 */            
/*                 04L1830, 5639-B43                                 */            
/*                 (C) Copyright IBM Corp. 1994, 1998                */ 
/*                                                                   */
/*********************************************************************/
/*                                                                   */
/* Function:                                                         */
/*                                                                   */
/* amqzscin.c is the XA Initialisation routine for CICS.             */
/* It contains the following functions:                              */
/*  CICS_XA_Init  -  CICS entry point for XA initialisation          */
/*                                                                   */
/*********************************************************************/
/*********************************************************************/
/*                                                                   */
/* Use the cl command to build amqzscin.obj by compiling using at    */
/* least the following:                                              */
/* cl -c -I<EncinaPath>\include -I<MQSeriesPath>\include             */
/*    -Gz -LD amqzscin.c                                             */
/*                                                                   */
/* Create a module definition file named mqmc1415.def containing     */
/* 3 lines of:                                                       */
/*   LIBRARY MQMC4SWI                                                */
/*   EXPORTS                                                         */
/*   CICS_XA_Init                                                    */
/*                                                                   */  
/* Use the lib command to build an export file & import library      */
/* using at least the following:                                     */  
/* lib -def:mqmc4swi.def -out:mqmc4swi.lib                           */
/*                                                                   */
/* If the lib command is successful then an mqmc4swi.exp will also   */
/* have been built.                                                  */
/*                                                                   */
/* Use the link command to build mqmc4swi.dll by linking using at    */
/* least the following:                                              */
/* link -dll -nod -out:mqmc4swi.dll                                  */
/*      amqzscin.obj <CicsPath>\lib\regxa_swxa.obj                   */
/*      mqmc4swi.exp mqmcics4.lib                                    */
/*      <CicsPath>\lib\libcicsrt.lib                                 */
/*      <DcePath>\lib\libdce.lib <DcePath>\lib\pthreads.lib          */
/*      <EncinaPath>\lib\libEncina.lib                               */
/*      <EncinaPath>\lib\libEncServer.lib                            */ 
/*      msvcrt.lib kernel32.lib                                      */
/*                                                                   */
/*********************************************************************/


/*********************************************************************/
/* Includes                                                          */
/*********************************************************************/

/*********************************************************************/
/* Select compiler specific header files                             */
/*********************************************************************/

#include <string.h>
#include <stdio.h>
#include <cmqc.h>

/*********************************************************************/
/* Select XA header file                                             */
/*********************************************************************/

#include <tmxa/xa.h>

/*********************************************************************/
/* External Data declarations                                        */
/*********************************************************************/
#define CALLCONV __cdecl
#define DLLIMPORT __declspec(dllimport)
extern DLLIMPORT struct xa_switch_t MQRMIXASwitch;
extern DLLIMPORT struct xa_switch_t MQRMIXASwitchDynamic;
extern struct xa_switch_t RegXA_xa_switch;
extern struct xa_switch_t *cics_xa_switch;

/*********************************************************************/
/* Data defined in this module                                       */
/*********************************************************************/

/*********************************************************************/
/* Local function declarations                                       */
/*********************************************************************/

extern void MQENTRY AMQCICSINIT(void *);
extern void CALLCONV cics_xa_init(void);

/*********************************************************************/
/* Function Definitions                                              */
/*********************************************************************/

/*********************************************************************/
/*                                                                   */
/* Function Name:  amqzscin                                          */
/*                                                                   */
/* Description: CICS XA initialisation.                              */
/*                                                                   */
/*********************************************************************/
/*                                                                   */
/* Function:                                                         */
/*                                                                   */
/*  amqzscin is called by CICS to initialise XA support for MQSeries */
/*                                                                   */
/* Input Parameters:  None                                           */
/*                                                                   */
/* Output Parameters: None                                           */
/*                                                                   */
/* InOut Parameters:  None                                           */
/*                                                                   */
/* Returns:           RegXA_xa_switch                                */
/*                                                                   */
/*********************************************************************/
struct xa_switch_t * CALLCONV CICS_XA_Init(void)
{
  /*******************************************************************/
  /* Set CICS pointer to our structure                               */
  /*******************************************************************/
  cics_xa_switch = &MQRMIXASwitchDynamic;

  /*******************************************************************/
  /* Initialise CICS support                                         */
  /*******************************************************************/
  cics_xa_init();

  /*******************************************************************/
  /* Tell MQ that CICS is available                                  */
  /* This call will cause MQ to callback to CICS on any MQCONN       */
  /* to determine the CICS UserId and transaction name, so that it   */
  /* can be used in authority checking and context.                  */
  /* For compatability with OS/2, a dummy parameter is given         */
  /*******************************************************************/
  AMQCICSINIT(NULL);

  /*******************************************************************/
  /* Return from function                                            */
  /*******************************************************************/
  return(&RegXA_xa_switch);

}

/*********************************************************************/
/*                                                                   */
/* End of amqzscin.c                                                 */
/*                                                                   */
/*********************************************************************/
